@@ -2,7 +2,7 @@ package App::MojoSlides;
 
 use Mojo::Base 'Mojolicious';
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 $VERSION = eval $VERSION;
 
 use App::MojoSlides::Slides;
@@ -39,12 +39,15 @@ sub startup {
       templates => undef,
       static    => undef,
       bootstrap_theme => undef,
+      more_tag_helpers => 1,
     },
   });
 
   # should this be optional?
   $self->include_data_handle_from_file(scalar $self->presentation_file);
 
+  $self->plugin('App::MojoSlides::MoreTagHelpers') if $self->config->{more_tag_helpers};
+
   if (my $path = $self->config->{templates}) {
     unshift @{ $self->renderer->paths }, ref $path ? @$path : $path;
   }
@@ -99,6 +102,10 @@ sub include_data_handle_from_file {
   require Mojo::Util;
   my $string = Mojo::Util::slurp($file);
   open my $handle, '<', \$string;
+  while (<$handle>) {
+    last if /^__DATA__/; # seek to __DATA__
+  }
+
   state $i = 0;
   my $class = 'App::MojoSlides::TextOfFile' . $i++;
   {
@@ -173,6 +180,10 @@ Of course you will still have to include them in some template for them to be in
 
 If true, the bootstrap-theme.min.css file will be included in the default layout.
 
+=item more_tag_helpers
+
+If true (by default), wrap lots more html tags into tag helpers from L<App::MojoSlides::MoreTagHelpers>.
+
 =back
 
 =head2 Slides from __DATA__
@@ -233,6 +244,8 @@ N.B. adding C<msOverlay="2-4"> to nearly any HTML tag will work as expect too!
 
 =back
 
+Plus the tag helpers from L<App::MojoSlides::MoreTagHelpers> if the configuration option is true.
+
 =head1 TECHNOLOGIES USED
 
 =over 
